@@ -393,7 +393,7 @@ SWListKey &VerseKey::ParseVerseList(char *buf, const char *defaultKey)
  * VerseKey::operator = - Equates this VerseKey to another VerseKey
  */
 
-SWKey &VerseKey::operator =(SWKey &ikey)
+SWKey &VerseKey::operator =(const SWKey &ikey)
 {
 	SWKey::operator =(ikey);
 
