@@ -15,7 +15,7 @@ GBFRTF::GBFRTF() {
 
 char GBFRTF::ProcessText(char *text, int maxlen)
 {
-	char *to, *from, token[20], tokpos;
+	char *to, *from, token[20], tokpos = 0;
 	bool intoken = false;
 	int len;
 
