@@ -5,7 +5,7 @@
 
 int main(int argc, char **argv)
 {
-	RawText webster("modules/texts/rawtext/webster/", "Webster", "Webster Text");
+	RawText webster("modules/texts/rawtext/websters/", "Webster", "Webster Text");
 	SWListKey	listkey;
 
 	if (argc != 2) {
