@@ -1,5 +1,6 @@
 #include <iostream.h>
 #include <stdio.h>
+#include <stdlib.h>
 
 #include <versekey.h>
 
@@ -9,8 +10,11 @@ main(int argc, char **argv)
 		fprintf(stderr, "usage: %s <\"string to parse\">\n", *argv);
 		exit(-1);
 	}
+	VerseKey DefaultVSKey;
 
-	SWListKey &list = VerseKey::ParseVerseList(argv[1]);
+	DefaultVSKey = "jas3:1";
+	
+	SWListKey &list = VerseKey::ParseVerseList(argv[1], DefaultVSKey);
 
 	while (!list.Error()) {
 		cout << (const char *)list << "\n";
